@@ -21,7 +21,7 @@ require XSLoader;
 use strict;
 use warnings;
 
-our $VERSION = "0.25";
+our $VERSION = "0.37";
 
 our @ISA = qw( Exporter );
 
@@ -48,6 +48,7 @@ our @EXPORT = qw(
 					CUPS_PRINTER_IMPLICIT
 					CUPS_PRINTER_DEFAULT
 					CUPS_PRINTER_FAX
+					CUPS_PRINTER_REJECTING
 					CUPS_PRINTER_OPTIONS
 					CUPS_VERSION
 					CUPS_VERSION_MAJOR
@@ -216,8 +217,7 @@ None.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003.
-D. Hageman (Dracken Technologies)
+Copyright (c) 2003-2004 D. Hageman (Dracken Technologies)
 All rights reserved.
 
 CUPS, the Common UNIX Printing System, the CUPS logo, and ESP Print Pro are the trademark property of Easy Software Products.
